@@ -238,7 +238,7 @@ std::optional<Glib::ustring> iter_in_tag(const Gtk::TextIter& iter, const Glib::
     for (const auto& iter_tag : iter.get_tags()) {
         Glib::ustring tag_name;
         iter_tag->get_property("name", tag_name);
-        spdlog::debug("TAG: {}", tag_name);
+        //spdlog::debug("TAG: {}", tag_name);
         if (str::startswith(tag_name, tag)) {
             return tag_name;
         }
@@ -280,15 +280,16 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, int depth)
 
                 Gtk::TextIter start_iter(text_iter);
                 Gtk::TextIter end_iter(text_iter);
-                while (!start_iter.starts_line()) {
-                    if (!start_iter.backward_word_start()) break;
+                while (not start_iter.starts_line()) {
+                    if (not start_iter.backward_word_start()) break;
                 }
 
-                while (!end_iter.ends_line()) {
-                    if (!end_iter.forward_word_end()) break;
+                while (not end_iter.ends_line() and not end_iter.get_child_anchor()) {
+                    if (not end_iter.forward_word_end()) break;
                 }
 
                 Glib::ustring txt(start_iter, end_iter);
+                //spdlog::debug("{} - {}", txt, txt.size());
 
                 auto mark = text_buffer->create_mark(end_iter, false);
 
@@ -297,7 +298,7 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, int depth)
 
                 text_iter = mark->get_iter();
                 text_buffer->delete_mark(mark);
-                spdlog::debug("INSERT DONE");
+                //spdlog::debug("INSERT DONE");
                 entry.children.emplace_back(fmt::format("node {} {}", node_id, anchor_txt), false, txt, depth + 1, h_lvl);
             }
             catch(std::invalid_argument&) {
@@ -320,7 +321,7 @@ void CtActions::_insert_toc_at_pos(Glib::RefPtr<Gtk::TextBuffer> text_buffer, co
         if (entry.is_node) {
             bullet_char = bullets_list[0];
         } else {
-            int bullet_index = entry.h_level + 1;
+            size_t bullet_index = entry.h_level + 1;
             if (bullet_index >= bullets_list.size()) {
                 bullet_index = bullets_list.size() - 1;
             }
@@ -346,7 +347,7 @@ void CtActions::_insert_toc_at_pos(Glib::RefPtr<Gtk::TextBuffer> text_buffer, co
 
 void find_toc_entries_and_children(std::list<TocEntry>& entries, CtActions& actions, CtMainWin& main_win, CtTreeIter& node, int depth)
 {
-    main_win.get_tree_store().treeview_safe_set_cursor(&main_win.get_tree_view(), node);
+    main_win.get_tree_view().set_cursor_safe(node);
     TocEntry entry = find_toc_entries(actions, node, depth);
     entries.emplace_back(entry);
 
@@ -370,7 +371,7 @@ void CtActions::toc_insert()
     CtTreeIter curr_node = _pCtMainWin->curr_tree_iter();
     if (toc_type == CtExporting::CURRENT_NODE) {
         auto txt_buff = curr_node.get_node_text_buffer();
-        _pCtMainWin->get_tree_store().treeview_safe_set_cursor(&_pCtMainWin->get_tree_view(), curr_node);
+        _pCtMainWin->get_tree_view().set_cursor_safe(curr_node);
 
         TocEntry entry = find_toc_entries(*this, curr_node, 0);
         entries.emplace_back(std::move(entry));
@@ -397,7 +398,7 @@ void CtActions::toc_insert()
 
     _insert_toc_at_pos(curr_node.get_node_text_buffer(), entries);
 
-    _pCtMainWin->get_tree_store().treeview_safe_set_cursor(&_pCtMainWin->get_tree_view(), curr_node);
+    _pCtMainWin->get_tree_view().set_cursor_safe(curr_node);
 }
 
 // Insert Timestamp
